@@ -25,12 +25,11 @@ class InstaTweet:
     """
 
     def __init__(self, profile: Profile):
-        """Initializes InstaTweet using a fully configured :class:`~.Profile`
+        """Initializes :class:`~.InstaTweet` using a fully configured :class:`~.Profile`
 
         The :class:`~.Profile` will be used to initialize an :class:`~.InstaClient` and :class:`~.TweetClient`
 
-        :Note:
-            Profile settings will only be validated when calling :meth:`~.start`
+        .. note:: InstaTweet won't :meth:`~.validate` the Profile settings until you call :meth:`~.start`
 
         :param profile: the :class:`~.Profile` to use for InstaTweeting
         """
@@ -96,13 +95,14 @@ class InstaTweet:
                 continue
 
             print(f'There are {len(new_posts)} posts to tweet for @{user}')
+            hashtags = profile.get_hashtags_for(user)
 
             for post in new_posts:
                 self.insta.download_post(post)
                 if not post.is_downloaded:
                     continue
 
-                tweeted = self.twitter.send_tweet(post, hashtags=profile.get_hashtags_for(user))
+                tweeted = self.twitter.send_tweet(post, hashtags)
                 if not tweeted:
                     continue
 
